@@ -2,6 +2,7 @@
 
 # {{{ constants and imports
 
+from __future__ import absolute_import, division, print_function
 import urwid
 
 try:
@@ -15,7 +16,7 @@ from pudb.py3compat import PY3, execfile, raw_input, xrange, \
 if PY3:
     ELLIPSIS = '…'
 else:
-    ELLIPSIS = unicode('…', 'utf-8')
+    ELLIPSIS = unicode('…', 'utf-8')  # noqa: F821
 
 from pudb.debugger import CONFIG
 
@@ -73,6 +74,7 @@ def get_str_safe_types():
         "SliceType TypeType TracebackType UnboundMethodType XRangeType".split()
         if hasattr(types, s)) + (WatchEvalError,)
 
+
 STR_SAFE_TYPES = get_str_safe_types()
 
 # }}}
@@ -196,8 +198,8 @@ class VariableWidget(urwid.FlowWidget):
             # Unicode is supported, use single character ellipsis
             for i in xrange(len(text)):
                 if len(text[i]) > maxcol:
-                    text[i] = (unicode(text[i][:maxcol-1])
-                    + ELLIPSIS + unicode(text[i][maxcol:]))
+                    text[i] = (unicode(text[i][:maxcol-1])  # noqa: F821
+                            + ELLIPSIS + unicode(text[i][maxcol:]))  # noqa: F821
                     # XXX: This doesn't work.  It just gives a ?
                     # Strangely, the following does work (it gives the …
                     # three characters from the right):
@@ -223,12 +225,24 @@ custom_stringifier_dict = {}
 def type_stringifier(value):
     if HAVE_NUMPY and isinstance(value, numpy.ndarray):
         return "ndarray %s %s" % (value.dtype, value.shape)
+
     elif isinstance(value, STR_SAFE_TYPES):
         try:
             return str(value)
         except Exception:
             pass
 
+    elif hasattr(value, "safely_stringify_for_pudb"):
+        try:
+            # (E.g.) Mock objects will pretend to have this
+            # and return nonsense.
+            result = value.safely_stringify_for_pudb()
+        except Exception:
+            pass
+        else:
+            if isinstance(result, string_types):
+                return result
+
     return type(value).__name__
 
 
@@ -280,6 +294,8 @@ class ValueWalker:
             self.add_item(prefix, label, repr(value), id_path, attr_prefix)
         elif isinstance(value, string_types):
             self.add_item(prefix, label, repr(value), id_path, attr_prefix)
+        elif value is None:
+            self.add_item(prefix, label, repr(value), id_path, attr_prefix)
         else:
             try:
                 displayed_value = get_stringifier(iinfo)(value)
